@@ -24,7 +24,7 @@ use {
 const PYOXIDIZER_CRATE_VERSION: &str = env!("CARGO_PKG_VERSION");
 
 /// Version string of pyembed crate from its Cargo.toml.
-const PYEMBED_CRATE_VERSION: &str = "0.19.0";
+const PYEMBED_CRATE_VERSION: &str = "0.20.0";
 
 /// URL of Git repository we were built from.
 const GIT_REPO_URL: &str = env!("GIT_REPO_URL");
@@ -98,7 +98,7 @@ pub static MINIMUM_RUST_VERSION: Lazy<semver::Version> =
     Lazy::new(|| semver::Version::new(1, 56, 0));
 
 /// Version of Rust toolchain to use for our managed Rust install.
-pub const RUST_TOOLCHAIN_VERSION: &str = "1.56.0";
+pub const RUST_TOOLCHAIN_VERSION: &str = "1.56.1";
 
 /// Target triples for Linux.
 pub static LINUX_TARGET_TRIPLES: Lazy<Vec<&'static str>> =
@@ -123,7 +123,7 @@ pub fn canonicalize_path(path: &Path) -> Result<PathBuf, std::io::Error> {
 
     // Strip \\?\ prefix on Windows and replace \ with /, which is valid.
     if cfg!(windows) {
-        let mut s = p.display().to_string().replace("\\", "/");
+        let mut s = p.display().to_string().replace('\\', "/");
         if s.starts_with("//?/") {
             s = s[4..].to_string();
         }
@@ -329,6 +329,8 @@ impl Environment {
             );
 
             let rust_env = if self.managed_rust {
+                // Compiler complains about lifetimes without the closure.
+                #[allow(clippy::redundant_closure)]
                 let target_triple = target_triple.unwrap_or_else(|| default_target_triple());
 
                 let toolchain = install_rust_toolchain(
