@@ -7,11 +7,9 @@ use {
         environment::{canonicalize_path, Environment, RustEnvironment},
         project_layout::initialize_project,
         py_packaging::{
-            binary::{
-                EmbeddedPythonContext, LibpythonLinkMode, PythonBinaryBuilder,
-                DEFAULT_PYTHON_CONFIG_FILENAME,
-            },
+            binary::{LibpythonLinkMode, PythonBinaryBuilder},
             distribution::AppleSdkInfo,
+            embedding::{EmbeddedPythonContext, DEFAULT_PYTHON_CONFIG_FILENAME},
         },
         starlark::eval::{EvaluationContext, EvaluationContextBuilder},
     },
@@ -451,18 +449,14 @@ pub fn build_pyembed_artifacts(
         return Ok(());
     }
 
-    let mut context: EvaluationContext = EvaluationContextBuilder::new(
-        env,
-        logger.clone(),
-        config_path.to_path_buf(),
-        target_triple.to_string(),
-    )
-    .extra_vars(extra_vars)
-    .release(release)
-    .verbose(verbose)
-    .resolve_target_optional(resolve_target)
-    .build_script_mode(true)
-    .try_into()?;
+    let mut context: EvaluationContext =
+        EvaluationContextBuilder::new(env, logger.clone(), config_path, target_triple.to_string())
+            .extra_vars(extra_vars)
+            .release(release)
+            .verbose(verbose)
+            .resolve_target_optional(resolve_target)
+            .build_script_mode(true)
+            .try_into()?;
 
     context.evaluate_file(config_path)?;
 
@@ -717,6 +711,29 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn test_empty_project_python_310() -> Result<()> {
+        let env = get_env()?;
+        let logger = get_logger()?;
+        let options = StandalonePythonExecutableBuilderOptions {
+            distribution_version: Some("3.10".to_string()),
+            ..Default::default()
+        };
+        let pre_built = options.new_builder()?;
+
+        build_python_executable(
+            &env,
+            &logger,
+            "myapp",
+            pre_built.as_ref(),
+            default_target_triple(),
+            "0",
+            false,
+        )?;
+
+        Ok(())
+    }
+
     #[test]
     fn test_empty_project_system_rust() -> Result<()> {
         let mut env = get_env()?;
@@ -787,6 +804,31 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    #[cfg(target_env = "msvc")]
+    fn test_empty_project_standalone_static_310() -> Result<()> {
+        let env = get_env()?;
+        let logger = get_logger()?;
+        let options = StandalonePythonExecutableBuilderOptions {
+            distribution_version: Some("3.10".to_string()),
+            distribution_flavor: DistributionFlavor::StandaloneStatic,
+            ..Default::default()
+        };
+        let pre_built = options.new_builder()?;
+
+        build_python_executable(
+            &env,
+            &logger,
+            "myapp",
+            pre_built.as_ref(),
+            default_target_triple(),
+            "0",
+            false,
+        )?;
+
+        Ok(())
+    }
+
     #[test]
     // Not supported on Windows.
     #[cfg(not(target_env = "msvc"))]
