@@ -144,6 +144,7 @@ impl LinkEntry {
     }
 }
 
+#[allow(unused)]
 #[derive(Debug, Deserialize)]
 struct PythonBuildExtensionInfo {
     in_core: bool,
@@ -159,6 +160,7 @@ struct PythonBuildExtensionInfo {
     variant: String,
 }
 
+#[allow(unused)]
 #[derive(Debug, Deserialize)]
 struct PythonBuildCoreInfo {
     objs: Vec<String>,
@@ -167,6 +169,7 @@ struct PythonBuildCoreInfo {
     static_lib: Option<String>,
 }
 
+#[allow(unused)]
 #[derive(Debug, Deserialize)]
 struct PythonBuildInfo {
     core: PythonBuildCoreInfo,
@@ -177,6 +180,7 @@ struct PythonBuildInfo {
     object_file_format: String,
 }
 
+#[allow(unused)]
 #[derive(Debug, Deserialize)]
 struct PythonJsonMain {
     version: String,
@@ -802,10 +806,9 @@ impl StandaloneDistribution {
                 } else if let Some(core) = &core_license {
                     LicensedComponent::new_spdx(
                         module,
-                        &core
-                            .spdx_expression()
+                        core.spdx_expression()
                             .ok_or_else(|| anyhow!("could not resolve SPDX license for core"))?
-                            .to_string(),
+                            .as_ref(),
                     )?
                 } else {
                     LicensedComponent::new_none(module)
@@ -1332,8 +1335,7 @@ impl PythonDistribution for StandaloneDistribution {
         let extension_modules = self
             .extension_modules
             .iter()
-            .map(|(_, exts)| exts.iter().map(|e| PythonResource::from(e.to_owned())))
-            .flatten();
+            .flat_map(|(_, exts)| exts.iter().map(|e| PythonResource::from(e.to_owned())));
 
         let module_sources = self.py_modules.iter().map(|(name, path)| {
             PythonResource::from(PythonModuleSource {
@@ -1346,21 +1348,17 @@ impl PythonDistribution for StandaloneDistribution {
             })
         });
 
-        let resource_datas = self
-            .resources
-            .iter()
-            .map(|(package, inner)| {
-                inner.iter().map(move |(name, path)| {
-                    PythonResource::from(PythonPackageResource {
-                        leaf_package: package.clone(),
-                        relative_name: name.clone(),
-                        data: FileData::Path(path.clone()),
-                        is_stdlib: true,
-                        is_test: self.is_stdlib_test_package(package),
-                    })
+        let resource_datas = self.resources.iter().flat_map(|(package, inner)| {
+            inner.iter().map(move |(name, path)| {
+                PythonResource::from(PythonPackageResource {
+                    leaf_package: package.clone(),
+                    relative_name: name.clone(),
+                    data: FileData::Path(path.clone()),
+                    is_stdlib: true,
+                    is_test: self.is_stdlib_test_package(package),
                 })
             })
-            .flatten();
+        });
 
         extension_modules
             .chain(module_sources)
@@ -1540,19 +1538,30 @@ pub mod tests {
                 .cloned()
                 .collect::<Vec<_>>();
 
-            let linux_dropped = vec![
-                ("_gdbm".to_string(), Some("default".to_string())),
-                ("readline".to_string(), Some("default".to_string())),
-            ];
-
-            let linux_added = vec![("readline".to_string(), Some("libedit".to_string()))];
+            // 3.10 distributions stopped shipping GPL licensed extensions.
+            let (linux_dropped, linux_added) =
+                if ["3.8", "3.9"].contains(&dist.python_major_minor_version().as_str()) {
+                    (
+                        vec![
+                            ("_gdbm".to_string(), Some("default".to_string())),
+                            ("readline".to_string(), Some("default".to_string())),
+                        ],
+                        vec![("readline".to_string(), Some("libedit".to_string()))],
+                    )
+                } else {
+                    (vec![], vec![])
+                };
 
             let (wanted_dropped, wanted_added) = match (
                 dist.python_major_minor_version().as_str(),
                 dist.target_triple(),
             ) {
                 (_, "x86_64-unknown-linux-gnu") => (linux_dropped.clone(), linux_added.clone()),
+                (_, "x86_64_v2-unknown-linux-gnu") => (linux_dropped.clone(), linux_added.clone()),
+                (_, "x86_64_v3-unknown-linux-gnu") => (linux_dropped.clone(), linux_added.clone()),
                 (_, "x86_64-unknown-linux-musl") => (linux_dropped.clone(), linux_added.clone()),
+                (_, "x86_64_v2-unknown-linux-musl") => (linux_dropped.clone(), linux_added.clone()),
+                (_, "x86_64_v3-unknown-linux-musl") => (linux_dropped.clone(), linux_added.clone()),
                 (_, "i686-pc-windows-msvc") => (vec![], vec![]),
                 (_, "x86_64-pc-windows-msvc") => (vec![], vec![]),
                 (_, "aarch64-apple-darwin") => (vec![], vec![]),
