@@ -40,11 +40,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("block-padding", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("byteorder", "MIT OR Unlicense")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -89,10 +84,19 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("crypto-common", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component = tugger_licensing::LicensedComponent::new_spdx("cty", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("data-encoding", "MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("digest", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -108,7 +112,7 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     res.push(component);
 
     let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("encoding_rs", "Apache-2.0 OR MIT")?;
+        tugger_licensing::LicensedComponent::new_spdx("fastrand", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -129,21 +133,11 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("getrandom", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("indoc", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("indoc-impl", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component = tugger_licensing::LicensedComponent::new_spdx("instant", "BSD-3-Clause")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -153,6 +147,10 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("itoa", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("jemalloc-sys", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -163,11 +161,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("lazy_static", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component = tugger_licensing::LicensedComponent::new_spdx("libc", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -191,7 +184,7 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     res.push(component);
 
     let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("memmap", "Apache-2.0 OR MIT")?;
+        tugger_licensing::LicensedComponent::new_spdx("memmap2", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -206,12 +199,12 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     res.push(component);
 
     let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("once_cell", "Apache-2.0 OR MIT")?;
+        tugger_licensing::LicensedComponent::new_spdx("num_threads", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
     let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("opaque-debug", "Apache-2.0 OR MIT")?;
+        tugger_licensing::LicensedComponent::new_spdx("once_cell", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -225,16 +218,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("paste", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("paste-impl", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("pathdiff", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -245,16 +228,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("ppv-lite86", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("proc-macro-hack", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("proc-macro2", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -274,6 +247,10 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("pyo3-ffi", "Apache-2.0")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component = tugger_licensing::LicensedComponent::new_spdx("pyo3-macros", "Apache-2.0")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -314,25 +291,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("rand", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("rand_chacha", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("rand_core", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
-    let mut component =
-        tugger_licensing::LicensedComponent::new_spdx("rand_hc", "Apache-2.0 OR MIT")?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component = tugger_licensing::LicensedComponent::new_spdx("redox_syscall", "MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
@@ -394,7 +352,7 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx("spin", "MIT")?;
+    let mut component = tugger_licensing::LicensedComponent::new_spdx("subtle", "BSD-3-Clause")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
@@ -421,6 +379,11 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
+    let mut component =
+        tugger_licensing::LicensedComponent::new_spdx("time-macros", "Apache-2.0 OR MIT")?;
+    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
+    res.push(component);
+
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("tugger-file-manifest", "MPL-2.0")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
@@ -461,13 +424,6 @@ pub fn pyembed_licenses() -> anyhow::Result<Vec<tugger_licensing::LicensedCompon
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
     res.push(component);
 
-    let mut component = tugger_licensing::LicensedComponent::new_spdx(
-        "wasi",
-        "Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT",
-    )?;
-    component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
-    res.push(component);
-
     let mut component =
         tugger_licensing::LicensedComponent::new_spdx("winapi", "Apache-2.0 OR MIT")?;
     component.set_flavor(tugger_licensing::ComponentFlavor::RustCrate);
